﻿using System;
using System.Collections.Generic;
using System.Linq;

namespace OkstraI18NTranslation
{
    class TranslationSubstringLengthSorter : IComparer<TranslationSubstring>
    {
        public int Compare(TranslationSubstring x, TranslationSubstring y)
        {
            if (x.GermanSubstring.Length > y.GermanSubstring.Length) return -1;
            if (x.GermanSubstring.Length == y.GermanSubstring.Length) return 0;
            return 1;
        }
    }

    public class TranslationSubstring
    {
        public TranslationSubstring(string german, string english)
        {
            GermanSubstring = german;
            EnglishSubstring = english;
        }

        public string GermanSubstring;
        public string EnglishSubstring;

        // override object.Equals
        public override bool Equals(object obj)
        {
            if (obj == null || GetType() != obj.GetType())
            {
                return false;
            }

            TranslationSubstring other = (TranslationSubstring)obj;

            return other.GermanSubstring == GermanSubstring && other.EnglishSubstring == EnglishSubstring;
        }

        // override object.GetHashCode
        public override int GetHashCode()
        {
            return EnglishSubstring.GetHashCode() * 17 + GermanSubstring.GetHashCode();
        }

        static public string Apply(List<TranslationSubstring> TranslationSubstrings, string to)
        {
            foreach (var ts in TranslationSubstrings)
            {
                if (to.Contains(ts.GermanSubstring))
                {
                    to = to.Replace(ts.GermanSubstring, ts.EnglishSubstring);
                }
            }

            return to;
        }

        static public List<TranslationSubstring> getOkstraTranslationSubstrings()
        {
            List<TranslationSubstring> ts = new List<TranslationSubstring>();



            ts.Add(new TranslationSubstring("<import namespace=\"http://www.okstra.de/okstra/2.017/okstra-typen\" schemaLocation=\"okstra-typen.xsd\"/>", "<import namespace=\"http://www.okstra.de/okstra/2.017/okstra-types\" schemaLocation=\"okstra-types.xsd\"/>"));
            ts.Add(new TranslationSubstring("<schema targetNamespace=\"http://www.okstra.de/okstra/2.017/okstra-typen\"", "<schema targetNamespace=\"http://www.okstra.de/okstra/2.017/okstra-types\""));
            ts.Add(new TranslationSubstring("xmlns:okstra-typen=\"http://www.okstra.de/okstra/2.017/okstra-typen\"", "xmlns:okstra-types=\"http://www.okstra.de/okstra/2.017/okstra-types\""));
            ts.Add(new TranslationSubstring("<include schemaLocation=\"S_Allgemeine_Geometrieobjekte.xsd\"/>", "<include schemaLocation=\"S_General_Geometry_Objects.xsd\"/>"));
            ts.Add(new TranslationSubstring("<include schemaLocation=\"S_Allgemeine_Objekte.xsd\"/>", "<include schemaLocation=\"S_General_Objects.xsd\"/>"));
            ts.Add(new TranslationSubstring("<include schemaLocation=\"Schluesseltabellen.xsd\"/>", "<include schemaLocation=\"Key_Tables.xsd\"/>"));
            ts.Add(new TranslationSubstring("<include schemaLocation=\"S_Strassennetz.xsd\"/>", "<include schemaLocation=\"S_Road_Network.xsd\"/>"));
            ts.Add(new TranslationSubstring("<!-- Eigenschaft fachliche_Bedeutung fehlt -->", "<!-- Property technical meaning missing -->"));
            ts.Add(new TranslationSubstring("<include schemaLocation=\"S_Topografie.xsd\"/>", "<include schemaLocation=\"S_Topography.xsd\"/>"));
            ts.Add(new TranslationSubstring("<!-- Eigenschaft Radius_zu_Beginn fehlt -->", "<!-- Property Radius_At_Start missing -->"));
            ts.Add(new TranslationSubstring("<include schemaLocation=\"Datentypen.xsd\"/>", "<include schemaLocation=\"Data_Types.xsd\"/>"));
            ts.Add(new TranslationSubstring("<!-- Eigenschaft Radius_am_Ende fehlt -->", "<!-- Property Radius_At_End missing -->"));
            ts.Add(new TranslationSubstring("<include schemaLocation=\"S_Entwurf.xsd\"/>", "<include schemaLocation=\"S_Design.xsd\"/>"));
            ts.Add(new TranslationSubstring("<!-- Eigenschaft Parameter fehlt -->", "<!-- Property Parameter missing -->"));
            ts.Add(new TranslationSubstring("S_Bauliche_Strasseneigenschaften.xsd", "S_Structural_Road_Properties.xsd"));
            ts.Add(new TranslationSubstring("<!-- Eigenschaft Art_DGM fehlt -->", "<!-- Property Type_DEM missing -->"));
            ts.Add(new TranslationSubstring("S_Arbeitsstelle_an_Strassen.xsd", "S_Work_Place_On_Road.xsd"));
            ts.Add(new TranslationSubstring("S_Dynamische_Verkehrsdaten.xsd", "S_Dynamic_Traffic_Data.xsd"));
            ts.Add(new TranslationSubstring("mit_Bezug_auf_allg_Punktobjekt", "With_Relation_To_General_Point_Object"));
            ts.Add(new TranslationSubstring("referenziert_Fremddatenbestand", "References_Foreign_Data"));
            ts.Add(new TranslationSubstring("S_Dynamische_Beschilderung.xsd", "S_Dynamic_Signage.xsd"));
            ts.Add(new TranslationSubstring("S_Liegenschaftsverwaltung.xsd", "S_Property_Management.xsd"));
            ts.Add(new TranslationSubstring("hat_Aufweitg_Verbreit_Verbind", "Has_Widening_Connection"));
            ts.Add(new TranslationSubstring("S_Statische_Beschilderung.xsd", "S_Static_Signage.xsd"));
            ts.Add(new TranslationSubstring("S_Allgemeine_Mengenberechnung", "S_General_Quantity_Calculation"));
            ts.Add(new TranslationSubstring("S_Netzaenderungsprotokoll.xsd", "S_Net_Activity_Log.xsd"));
            ts.Add(new TranslationSubstring("Koordinatenreferenzsystem_3D", "Coordinate_Reference_System_3D"));
            ts.Add(new TranslationSubstring("Koordinatenreferenzsystem_2D", "Coordinate_Reference_System_2D"));
            ts.Add(new TranslationSubstring("Aufweitung_Verbreit_Verbind", "Widening_Connection"));
            ts.Add(new TranslationSubstring("S_Strassenzustandsdaten.xsd", "S_Road_Condition_Data.xsd"));
            ts.Add(new TranslationSubstring("S_Strassenausstattungen.xsd", "S_Road_Equipment.xsd"));
            ts.Add(new TranslationSubstring("Strassenkategorie_RAS_N_RIN", "Road_Class_RAS_N_RIN"));
            ts.Add(new TranslationSubstring("Art_des_betroffenen_Objekts", "Type_Of_Involved_Object"));
            ts.Add(new TranslationSubstring("<simpleType name=\"Groesse\">", "<simpleType name=\"Size\">"));
            ts.Add(new TranslationSubstring("type=\"okstra-typen:Groesse\"", "type=\"okstra-typen:Size\""));
            ts.Add(new TranslationSubstring("beginnt_bei_Achshauptpunkt", "Starts_At_Alignment_Master_Point"));
            ts.Add(new TranslationSubstring("Anfangsstation_rechnerisch", "Start_Station_Computed"));
            ts.Add(new TranslationSubstring("allgemeines_Flaechenobjekt", "General_Area_Object"));
            ts.Add(new TranslationSubstring("S_Strassenverzeichnis.xsd", "S_Road_Directory.xsd"));
            ts.Add(new TranslationSubstring("Boeschungskantenabschnitt", "Embankment_Edge_Region"));
            ts.Add(new TranslationSubstring("Koordinatenreferenzsystem", "Coordinate_Reference_System"));
            ts.Add(new TranslationSubstring("referenziert_Fremdobjekt", "References_Foreign_Object"));
            ts.Add(new TranslationSubstring("Art_Geschwindigkeitsband", "Type_Speed_Band"));
            ts.Add(new TranslationSubstring("allgemeines_Linienobjekt", "General_Line_Object"));
            ts.Add(new TranslationSubstring("Koordinatenherkunft_Land", "Coordinate_Source_State"));
            ts.Add(new TranslationSubstring("Geometrie_Streckenobjekt", "Geometry_Stretch"));
            ts.Add(new TranslationSubstring("hat_Geschwindigkeitsband", "Has_Speed_Band"));
            ts.Add(new TranslationSubstring("endet_bei_Achshauptpunkt", "Ends_At_Alignment_Master_Point"));
            ts.Add(new TranslationSubstring("Sichtweite_erforderlich", "Visibility_Required"));
            ts.Add(new TranslationSubstring("TagesgruppePropertyType", "DayGroupPropertyType"));
            ts.Add(new TranslationSubstring("automatische_Berechnung", "Automatic_Calculation"));
            ts.Add(new TranslationSubstring("zu_Kommunikationsobjekt", "To_Communication_Object"));
            ts.Add(new TranslationSubstring("S_Lichtsignalanlage.xsd", "S_Traffic_Light_System.xsd"));
            ts.Add(new TranslationSubstring("horizontale_Ausrichtung", "Horizontal_Orientation"));
            ts.Add(new TranslationSubstring("S_Projektressourcen.xsd", "S_Project_Resources.xsd"));
            ts.Add(new TranslationSubstring("hat_Strassenbezeichnung", "Has_Road_Name"));
            ts.Add(new TranslationSubstring("hat_Abstand_Achse_Achse", "Has_Distance_Alignment_Alignment"));
            ts.Add(new TranslationSubstring("Abstand_Achse_LinieType", "Distance_Alignment_Line_Type"));
            ts.Add(new TranslationSubstring("allgemeines_Punktobjekt", "General_PointObject"));
            ts.Add(new TranslationSubstring("Quelle_der_Information", "Source_Of_Information"));
            ts.Add(new TranslationSubstring("S_Vermessungspunkt.xsd", "S_Triangulation_Station.xsd"));
            ts.Add(new TranslationSubstring("S_Kostenmanagement.xsd", "S_Cost_Management.xsd"));
            ts.Add(new TranslationSubstring("Beginn_von_Achselement", "Start_Of_Alignment_Element"));
            ts.Add(new TranslationSubstring("geloescht_von_Ereignis", "Deleted_By_Event"));
            ts.Add(new TranslationSubstring("S_Umfeldmessstelle.xsd", "S_Environment_Monitoring_Station.xsd"));
            ts.Add(new TranslationSubstring("Art_Profillinie_sonst", "Type_Profile_Line_Otherwise"));
            ts.Add(new TranslationSubstring("vertikale_Ausrichtung", "Vertical_Orientation"));
            ts.Add(new TranslationSubstring("S_Schwertransport.xsd", "S_Heavy_Transport.xsd"));
            ts.Add(new TranslationSubstring("Geschwindigkeitsband", "Speed_Band"));
            ts.Add(new TranslationSubstring("weitere_Tagesgruppen", "Further_Day_Groups"));
            ts.Add(new TranslationSubstring("Strassenelementpunkt", "Road_Element_Point"));
            ts.Add(new TranslationSubstring("Sichtweite_vorhanden", "Visibility_Existing"));
            ts.Add(new TranslationSubstring("gehoert_zu_Boeschung", "Belongs_to_Embankment"));
            ts.Add(new TranslationSubstring("S_Flaechenmodell.xsd", "S_Area_Model.xsd"));
            ts.Add(new TranslationSubstring("Bedeutung_Berechnung", "Meaning_Calculation"));
            ts.Add(new TranslationSubstring("erzeugt_von_Ereignis", "Created_By_Event"));
            ts.Add(new TranslationSubstring("bez_auf_verallg_Spur", "Related_To_General_Trace"));
            ts.Add(new TranslationSubstring("S_Historisierung.xsd", "S_Historicisation.xsd"));
            ts.Add(new TranslationSubstring("Kommunikationsobjekt", "Communication_Object"));
            ts.Add(new TranslationSubstring("Abstand_Achse_Linie", "Distance_Alignment_Line"));
            ts.Add(new TranslationSubstring("base=\"okstra-typen:", "base=\"okstra-types:"));
            ts.Add(new TranslationSubstring("type=\"okstra-typen:", "type=\"okstra-types:"));
            ts.Add(new TranslationSubstring("auf_Strassenelement", "On_Road_Element"));
            ts.Add(new TranslationSubstring("Abstand_Achse_Achse", "Distance_Alignment_Alignment"));
            ts.Add(new TranslationSubstring("Strassenbezeichnung", "Road_Name"));
            ts.Add(new TranslationSubstring("historisches_Objekt", "Historic_Object"));
            ts.Add(new TranslationSubstring("fachliche_Bedeutung", "Technical_Meaning"));
            ts.Add(new TranslationSubstring("S_Allgemene_Objekte", "S_General_Objects"));
            ts.Add(new TranslationSubstring("Kosten_Land_bisher", "Costs_State_Until_Now"));
            ts.Add(new TranslationSubstring("Strassenteilstueck", "Road_Section"));
            ts.Add(new TranslationSubstring("Netzfunktion_Achse", "Net_Function_Alignment"));
            ts.Add(new TranslationSubstring("Migrationshinweise", "Migration_Notes"));
            ts.Add(new TranslationSubstring("Landschaftsplanung", "Landscape_Planning"));
            ts.Add(new TranslationSubstring("Art_der_Verziehung", "Type_of_Displacement"));
            ts.Add(new TranslationSubstring("Schluesseltabellen", "Key_Tables"));
            ts.Add(new TranslationSubstring("Beschriftungsfahne", "Tag"));
            ts.Add(new TranslationSubstring("XML Instanzdateien", "XML instance files"));
            ts.Add(new TranslationSubstring("Status_Eigenschaft", "Status_Property"));
            ts.Add(new TranslationSubstring("gehoert_zu_Trasse", "Belongs_To_Alignment"));
            ts.Add(new TranslationSubstring("Dreiwertige_Logik", "Trivalent_Logic"));
            ts.Add(new TranslationSubstring("Art_Horizontlinie", "Type_Terrain_Profile"));
            ts.Add(new TranslationSubstring("hat_Horizontlinie", "Has_Terrain_Profile"));
            ts.Add(new TranslationSubstring("Dreiecksbedeutung", "Triangle_Meaning"));
            ts.Add(new TranslationSubstring("Seiteneigenschaft", "Edge_Property"));
            ts.Add(new TranslationSubstring("Flaechengeometrie", "Area_Geometry"));
            ts.Add(new TranslationSubstring("S_Hausnummern.xsd", "S_House_Numbers.xsd"));
            ts.Add(new TranslationSubstring("Textausgestaltung", "Text_Style"));
            ts.Add(new TranslationSubstring("S_Grunderwerb.xsd", "S_Land_Acquisition.xsd"));
            ts.Add(new TranslationSubstring("Typ_der_Anschrift", "Type_Of_Adress"));
            ts.Add(new TranslationSubstring("Abstand_zur_Achse", "Distance_To_Alignment"));
            ts.Add(new TranslationSubstring("Strassenkategorie", "Road_Class_RAS_N_RIN"));
            ts.Add(new TranslationSubstring("Art_des_Horizonts", "Type_of_Horizon"));
            ts.Add(new TranslationSubstring("Radius_zu_Beginn", "Radius_At_Start"));
            ts.Add(new TranslationSubstring("gehoert_zu_Achse", "Belongs_To_Alignment"));
            ts.Add(new TranslationSubstring("Art_verallg_Spur", "Type_General_Trace"));
            ts.Add(new TranslationSubstring("Tag_in_der_Woche", "Day_Of_The_Week"));
            ts.Add(new TranslationSubstring("S_Kreuzungen.xsd", "S_Junctions.xsd"));
            ts.Add(new TranslationSubstring("Informationstext", "Description"));
            ts.Add(new TranslationSubstring("Querneigungsband", "Slope_Band"));
            ts.Add(new TranslationSubstring("Station_zw_Achse", "Station_Second_Alignment"));
            ts.Add(new TranslationSubstring("ist_Gegenspur_zu", "Is_Opposite_Trace_To"));
            ts.Add(new TranslationSubstring("Landesschluessel", "State_Key"));
            ts.Add(new TranslationSubstring("hat_zweite_Achse", "Has_Second_Alignment"));
            ts.Add(new TranslationSubstring("Stundenkilometer", "Kilometer_Per_Hour"));
            ts.Add(new TranslationSubstring("Horizontkennzahl", "Horizon_Classification_Number"));
            ts.Add(new TranslationSubstring("zu_OKSTRA_Objekt", "To_OKSTRA_Object"));
            ts.Add(new TranslationSubstring("Einfuegeposition", "Insertion_Position"));
            ts.Add(new TranslationSubstring("hat_verallg_Spur", "Has_General_Trace"));
            ts.Add(new TranslationSubstring("S_Oekologie.xsd", "S_Ecology.xsd"));
            ts.Add(new TranslationSubstring("hat_Sichtweiten", "Has_Visibilites"));
            ts.Add(new TranslationSubstring("Verziehungsform", "Transition_Style"));
            ts.Add(new TranslationSubstring("hat_Achselement", "Has_Horizontal_Alignment_Element"));
            ts.Add(new TranslationSubstring("Art_Profillinie", "Type_Profile_Line"));
            ts.Add(new TranslationSubstring("Art_Sichtweiten", "Type_Visibilities"));
            ts.Add(new TranslationSubstring("Erfassungsdatum", "Entry_Date"));
            ts.Add(new TranslationSubstring("ist_Fahrspur_zu", "Is_Driving_Lane_To"));
            ts.Add(new TranslationSubstring("Symbolbedeutung", "Symbol_Meaning"));
            ts.Add(new TranslationSubstring("Liniengeometrie", "Line_Geometry"));
            ts.Add(new TranslationSubstring("Prozent_Neigung", "Percentage_Slope"));
            ts.Add(new TranslationSubstring("hat_Hoehe_Linie", "Has_Height_Line"));
            ts.Add(new TranslationSubstring("Tangentenlaenge", "Tangent_Lenght"));
            ts.Add(new TranslationSubstring("DGM_proprietaer", "DEM_Proprietary"));
            ts.Add(new TranslationSubstring("Geschwindigkeit", "Speed"));
            ts.Add(new TranslationSubstring("zu_Beschriftung", "To_Label"));
            ts.Add(new TranslationSubstring("Strassennummer", "Road_Number"));
            ts.Add(new TranslationSubstring("S_Strassennetz", "S_RoadNetwork"));
            ts.Add(new TranslationSubstring("Differenzhoehe", "Difference_Height"));
            ts.Add(new TranslationSubstring("Farbwert_gruen", "Color_Value_Green"));
            ts.Add(new TranslationSubstring("hat_Deckenbuch", "Has_Pavement_Design_Specification"));
            ts.Add(new TranslationSubstring("Achshauptpunkt", "Alignment_Master_Point"));
            ts.Add(new TranslationSubstring("Dreiecksnummer", "Triangle_Number"));
            ts.Add(new TranslationSubstring("Bezugsposition", "Reference_Position"));
            ts.Add(new TranslationSubstring("S_Kataster.xsd", "S_Land_Register.xsd"));
            ts.Add(new TranslationSubstring("Strassenklasse", "Road_Class"));
            ts.Add(new TranslationSubstring("Neigungswinkel", "Inclination"));
            ts.Add(new TranslationSubstring("hat_Bruchkante", "Has_Breakline"));
            ts.Add(new TranslationSubstring("hat_Querprofil", "Has_Cross_Section"));
            ts.Add(new TranslationSubstring("Scheitelradius", "Vertex_Radius"));
            ts.Add(new TranslationSubstring("Achselementtyp", "Type_Axis_Element"));
            ts.Add(new TranslationSubstring("von_Deckenbuch", "Of_Pavement_Design_Specification"));
            ts.Add(new TranslationSubstring("Multigeometrie", "Multi_Geometry"));
            ts.Add(new TranslationSubstring("Punktgeometrie", "Point_Geometry"));
            ts.Add(new TranslationSubstring("hat_Ausrundung", "Has_Rounding"));
            ts.Add(new TranslationSubstring("Radius_am_Ende", "Radius_At_End"));
            ts.Add(new TranslationSubstring("Bestandsstatus", "Inventory_Status"));
            ts.Add(new TranslationSubstring("S_Bauwerke.xsd", "S_Buildings.xsd"));
            ts.Add(new TranslationSubstring("Sachbearbeiter", "Case_Worker"));
            ts.Add(new TranslationSubstring("Farbwert_blau", "Color_Value_Blue"));
            ts.Add(new TranslationSubstring("Adresszeile_2", "Address_Line_2"));
            ts.Add(new TranslationSubstring("Monat_im_Jahr", "Month_In_Year"));
            ts.Add(new TranslationSubstring("Strassenpunkt", "Road_Point"));
            ts.Add(new TranslationSubstring("S_Verkehr.xsd", "S_Traffic.xsd"));
            ts.Add(new TranslationSubstring("OKSTRA_Objekt", "OKSTRA_Object"));
            ts.Add(new TranslationSubstring("hat_Hoehenzug", "Has_Independent_Vertical_Alignment_Trace"));
            ts.Add(new TranslationSubstring("Stunde_am_Tag", "Hour_Of_Day"));
            ts.Add(new TranslationSubstring("Breite_rechts", "Width_Right"));
            ts.Add(new TranslationSubstring("Art_Boeschung", "Type_Embankment"));
            ts.Add(new TranslationSubstring("Horizontlinie", "Terrain_Profile"));
            ts.Add(new TranslationSubstring("Adresszeile_4", "Address_Line_4"));
            ts.Add(new TranslationSubstring("Adresszeile_3", "Address_Line_3"));
            ts.Add(new TranslationSubstring("Textbedeutung", "Text_Meaning"));
            ts.Add(new TranslationSubstring("hat_Grad_Koor", "Has_VPI_Coor"));
            ts.Add(new TranslationSubstring("hat_Gradiente", "Has_Vertical_Alignment"));
            ts.Add(new TranslationSubstring("hat_Gegenspur", "Has_Opposite_Trace"));
            ts.Add(new TranslationSubstring("Art_Gradiente", "Type_Vertical_Alignment"));
            ts.Add(new TranslationSubstring("in_Bruchkante", "In_Breakline"));
            ts.Add(new TranslationSubstring("Woche_im_Jahr", "Week_In_Year"));
            ts.Add(new TranslationSubstring("S_Unfall.xsd", "S_Accident.xsd"));
            ts.Add(new TranslationSubstring("Beschriftung", "Label"));
            ts.Add(new TranslationSubstring("verallg_Spur", "General_Trace"));
            ts.Add(new TranslationSubstring("Bestandsplan", "As_Completed_Drawing"));
            ts.Add(new TranslationSubstring("hat_Dreiecke", "Has_Triangles"));
            ts.Add(new TranslationSubstring("Postleitzahl", "Postcode"));
            ts.Add(new TranslationSubstring("hat_QP_Punkt", "Has_CP_Point"));
            ts.Add(new TranslationSubstring("hat_QN_Punkt", "Has_CS_Point"));
            ts.Add(new TranslationSubstring("RGB_Farbwert", "RGB_Color_Value"));
            ts.Add(new TranslationSubstring("S_Topografie", "S_Topography"));
            ts.Add(new TranslationSubstring("Netzfunktion", "Net_Function"));
            ts.Add(new TranslationSubstring("Breite_links", "Width_Left"));
            ts.Add(new TranslationSubstring("Landesnummer", "State_Number"));
            ts.Add(new TranslationSubstring("hat_HZ_Punkt", "Has_IVAT_Point"));
            ts.Add(new TranslationSubstring("Schrifthoehe", "Font_Size"));
            ts.Add(new TranslationSubstring("Hochbordspur", "Curb_Step_Trace"));
            ts.Add(new TranslationSubstring("Objektklasse", "Object_Class"));
            ts.Add(new TranslationSubstring("hat_HB_Punkt", "Has_Curb_Step_Point"));
            ts.Add(new TranslationSubstring("Schriftfarbe", "Font_Color"));
            ts.Add(new TranslationSubstring("Tag_im_Monat", "Day_In_Month"));
            ts.Add(new TranslationSubstring("hat_BR_Punkt", "Has_LB_Point"));
            ts.Add(new TranslationSubstring("hat_Hor_Koor", "Has_Hor_Coor"));
            ts.Add(new TranslationSubstring("Beschreibung", "Description"));
            ts.Add(new TranslationSubstring("Farbwert_rot", "Color_Value_Red"));
            ts.Add(new TranslationSubstring("hat_Fahrspur", "Has_Driving_Lane"));
            ts.Add(new TranslationSubstring("Profillinie", "Profile_Line"));
            ts.Add(new TranslationSubstring("hat_SW_Koor", "Has_VIS_Coor"));
            ts.Add(new TranslationSubstring("Breitenband", "Lane_Border"));
            ts.Add(new TranslationSubstring("Achselement", "Horizontal_Alignment_Element"));
            ts.Add(new TranslationSubstring("abs_Abstand", "ABS_Distance"));
            ts.Add(new TranslationSubstring("gueltig_von", "Valid_From"));
            ts.Add(new TranslationSubstring("hat_Strecke", "Has_Stretch"));
            ts.Add(new TranslationSubstring("Systemdatum", "System_Date"));
            ts.Add(new TranslationSubstring("Bezeichnung", "Name"));
            ts.Add(new TranslationSubstring("Sichtweiten", "Visibilites"));
            ts.Add(new TranslationSubstring("Querneigung", "Slope"));
            ts.Add(new TranslationSubstring("Hoehe_unten", "Height_Bottom"));
            ts.Add(new TranslationSubstring("Hoehe_Linie", "Height_Line"));
            ts.Add(new TranslationSubstring("Adressdaten", "Address_Data"));
            ts.Add(new TranslationSubstring("gueltig_bis", "Valid_Until"));
            ts.Add(new TranslationSubstring("Punktnummer", "Point_Number"));
            ts.Add(new TranslationSubstring("undeutlich", "Fuzzy"));
            ts.Add(new TranslationSubstring("Elementtyp", "Element_Type"));
            ts.Add(new TranslationSubstring("hat_V_Koor", "Has_V_Coor"));
            ts.Add(new TranslationSubstring("in_Dreieck", "In_Triangle"));
            ts.Add(new TranslationSubstring("hat_Punkte", "Has_Points"));
            ts.Add(new TranslationSubstring("zu_Strasse", "To_Road"));
            ts.Add(new TranslationSubstring("ASB_Objekt", "ASB_Object"));
            ts.Add(new TranslationSubstring("Drehwinkel", "Rotation_Angle"));
            ts.Add(new TranslationSubstring("Hoehe_fest", "Height_fixed"));
            ts.Add(new TranslationSubstring("Querprofil", "Cross_Section"));
            ts.Add(new TranslationSubstring("Ausrundung", "Rounding"));
            ts.Add(new TranslationSubstring("Spurnummer", "Trace_Number"));
            ts.Add(new TranslationSubstring("Deckenbuch", "Pavement_Design_Specification"));
            ts.Add(new TranslationSubstring("Bruchkante", "Breakline"));
            ts.Add(new TranslationSubstring("hat_Symbol", "Has_Symbol"));
            ts.Add(new TranslationSubstring("Schriftart", "Font_Type"));
            ts.Add(new TranslationSubstring("Hoehe_oben", "Height_Top"));
            ts.Add(new TranslationSubstring("Berechnung", "Calculation"));
            ts.Add(new TranslationSubstring("hat_Achse", "Has_Alignment"));
            ts.Add(new TranslationSubstring("Gradiente", "Vertical_Alignment"));
            ts.Add(new TranslationSubstring("Station_2", "Station_2"));
            ts.Add(new TranslationSubstring("hat_Punkt", "Has_Point"));
            ts.Add(new TranslationSubstring("Hoehenzug", "Independent_Vertical_Alignment_Trace"));
            ts.Add(new TranslationSubstring("Boeschung", "Embankment"));
            ts.Add(new TranslationSubstring("von_Achse", "Of_Horizontal_Alignment"));
            ts.Add(new TranslationSubstring("S_Entwurf", "S_Design"));
            ts.Add(new TranslationSubstring("RGB_Farbe", "RGB_Color"));
            ts.Add(new TranslationSubstring("Parameter", "Parameter"));
            ts.Add(new TranslationSubstring("hat_Kehle", "Has_Fillet"));
            ts.Add(new TranslationSubstring("Grad_Koor", "VPI_Coor"));
            ts.Add(new TranslationSubstring("Art_Achse", "Type_Alignment"));
            ts.Add(new TranslationSubstring("Station_1", "Station_1"));
            ts.Add(new TranslationSubstring("QN_Punkt", "CS_Point"));
            ts.Add(new TranslationSubstring("QP_Punkt", "CP_Point"));
            ts.Add(new TranslationSubstring("Textfeld", "Text_Box"));
            ts.Add(new TranslationSubstring("Postfach", "Mailbox"));
            ts.Add(new TranslationSubstring("Sekunden", "Seconds"));
            ts.Add(new TranslationSubstring("von_Spur", "Of_Trace"));
            ts.Add(new TranslationSubstring("Richtung", "Direction"));
            ts.Add(new TranslationSubstring("HZ_Punkt", "IVAT_Point"));
            ts.Add(new TranslationSubstring("BR_Punkt", "LB_Point"));
            ts.Add(new TranslationSubstring("Hor_Koor", "Terrain_Profile_Coor"));
            ts.Add(new TranslationSubstring("HB_Punkt", "Curb_Step_Point"));
            ts.Add(new TranslationSubstring("Langtext", "Long_Description"));
            ts.Add(new TranslationSubstring("Einheit", "Unit"));
            ts.Add(new TranslationSubstring("Groesse", "Size"));
            ts.Add(new TranslationSubstring("Minuten", "Minutes"));
            ts.Add(new TranslationSubstring("Strasse", "Road"));
            ts.Add(new TranslationSubstring("Stunden", "Hours"));
            ts.Add(new TranslationSubstring("SW_Koor", "VIS_Coor"));
            ts.Add(new TranslationSubstring("Station", "Station"));
            ts.Add(new TranslationSubstring("Uhrzeit", "Time"));
            ts.Add(new TranslationSubstring("Dreieck", "Triangle"));
            ts.Add(new TranslationSubstring("Art_DGM", "Type_DEM"));
            ts.Add(new TranslationSubstring("Kennung", "Identifier"));
            ts.Add(new TranslationSubstring("Abstand", "Distance"));
            ts.Add(new TranslationSubstring("Trasse", "Road_Design"));
            ts.Add(new TranslationSubstring("Kasten", "Box"));
            ts.Add(new TranslationSubstring("Status", "Status"));
            ts.Add(new TranslationSubstring("Breite", "Width"));
            ts.Add(new TranslationSubstring("V_Koor", "V_Coor"));
            ts.Add(new TranslationSubstring("Monate", "Months"));
            ts.Add(new TranslationSubstring("in_DGM", "In_DEM"));
            ts.Add(new TranslationSubstring("Laenge", "Length"));
            ts.Add(new TranslationSubstring("FachId", "Technical_Id"));
            ts.Add(new TranslationSubstring("Hoehe", "Height"));
            ts.Add(new TranslationSubstring("Kehle", "Fillet"));
            ts.Add(new TranslationSubstring("Achse", "Alignment"));
            ts.Add(new TranslationSubstring("Jahre", "Years"));
            ts.Add(new TranslationSubstring("Titel", "Title"));
            ts.Add(new TranslationSubstring("Datum", "Date"));
            ts.Add(new TranslationSubstring("Monat", "Month"));
            ts.Add(new TranslationSubstring("Meter", "Meter"));
            ts.Add(new TranslationSubstring("Land", "State"));
            ts.Add(new TranslationSubstring("Tage", "Days"));
            ts.Add(new TranslationSubstring("Text", "Text"));
            ts.Add(new TranslationSubstring("Spur", "Trace"));
            ts.Add(new TranslationSubstring("Jahr", "Year"));
            ts.Add(new TranslationSubstring("Tag", "Day"));
            ts.Add(new TranslationSubstring("DGM", "DEM"));
            ts.Add(new TranslationSubstring("Ort", "Location"));





            ts.Sort(new TranslationSubstringLengthSorter());
            
            List<TranslationSubstring> noDupes = ts.Distinct().ToList();

            return noDupes;
        }
    }
}
